@@ -1,8 +1,8 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2009 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMPEXT, NX protocol compression and NX extensions to this software  */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
@@ -54,30 +54,6 @@ extern "C" {
 #define NXNoResource           256 + 1
 #define NXAnyResource          256 + 2
 
-/*
- * Flush the Xlib display buffer and then the
- * NX transport.
- */
-
-extern int NXFlushDisplay(
-#if NeedFunctionPrototypes
-    Display*            /* display */,
-    int                 /* what */
-#endif
-);
-
-/*
- * Query the number of bytes enqueued to the
- * NX transport.
- */
-
-extern int NXQueryDisplay(
-#if NeedFunctionPrototypes
-    Display*            /* display */,
-    int                 /* what */
-#endif
-);
-
 /*
  * Initialize the internal structures used by
  * the library. Should be executed again after
@@ -102,39 +78,25 @@ extern int NXResetDisplay(
 );
 
 /*
- * If the parameter is true, the Xlib I/O error
- * handler will return, instead of quitting the
- * program. The function returns the previous
- * value.
+ * Set the NX display flush policy. The policy can
+ * be either NXFlushDeferred or NXFlushImmediate.
  */
 
-extern int NXHandleDisplayError(
+extern int NXSetDisplayPolicy(
 #if NeedFunctionPrototypes
-    int                 /* value */
+    Display*            /* display */,
+    int                 /* policy */
 #endif
 );
 
 /*
- * Check that the value of the XlibDisplayIOError
- * flag. The internal display structures are not
- * exposed to the client program, so we need this
- * ancillary function.
+ * Set the display output buffer size.
  */
 
-extern int NXQueryDisplayError(
+extern int NXSetDisplayBuffer(
 #if NeedFunctionPrototypes
-    Display*            /* display */
-#endif
-);
-
-/*
- * Shutdown the display descriptor and force Xlib
- * to set the I/O error flag.
- */
-
-extern Bool NXForceDisplayError(
-#if NeedFunctionPrototypes
-    Display*            /* display */
+    Display*            /* display */,
+    int                 /* size */
 #endif
 );
 
@@ -153,14 +115,88 @@ extern int NXUnsetLibraryPath(
 );
 
 /*
- * Set the NX display flush policy. The policy can
- * be either NXFlushDeferred or NXFlushImmediate.
+ * If the parameter is true, the Xlib I/O error
+ * handler will return, instead of quitting the
+ * program. The function returns the previous
+ * value.
  */
 
-extern int NXSetDisplayPolicy(
+extern int NXHandleDisplayError(
+#if NeedFunctionPrototypes
+    int                 /* value */
+#endif
+);
+
+/*
+ * Shutdown the display descriptor and force Xlib
+ * to set the I/O error flag.
+ */
+
+extern Bool NXForceDisplayError(
+#if NeedFunctionPrototypes
+    Display*            /* display */
+#endif
+);
+
+/*
+ * Check the value of the XlibDisplayIOError flag.
+ * If not set, try to call the display error hand-
+ * ler to give to the application a chance to see
+ * whether it needs to close the connection.
+ */
+
+extern int NXDisplayError(
+#if NeedFunctionPrototypes
+    Display*            /* display */
+#endif
+);
+
+/*
+ * Query the number of bytes readable from the
+ * display connection.
+ */
+
+extern int NXDisplayReadable(
+#if NeedFunctionPrototypes
+    Display*            /* display */
+#endif
+);
+
+/*
+ * Query the number of the outstanding bytes to
+ * flush to the display connection.
+ */
+
+extern int NXDisplayFlushable(
+#if NeedFunctionPrototypes
+    Display*            /* display */
+#endif
+);
+
+/*
+ * Return a value between 0 and 9 indicating the
+ * congestion level of the NX transport based on
+ * the tokens remaining. A value of 9 means that
+ * the link is congested and no further data can
+ * be sent.
+ */
+
+extern int NXDisplayCongestion(
+#if NeedFunctionPrototypes
+    Display*            /* display */
+#endif
+);
+
+/*
+ * Flush the Xlib display buffer and/or the
+ * outstanding data accumulated by the NX
+ * transport.
+ */
+
+extern int NXFlushDisplay(
 #if NeedFunctionPrototypes
     Display*            /* display */,
-    int                 /* policy */
+    int                 /* what */
 #endif
 );
 
@@ -175,6 +211,11 @@ extern NXDisplayErrorPredicate NXSetDisplayErrorPredicate(
 #endif
 );
 
+/*
+ * Called when the display blocks waiting to read or
+ * write more data.
+ */
+
 extern NXDisplayBlockHandler NXSetDisplayBlockHandler(
 #if NeedFunctionPrototypes
     NXDisplayBlockHandler /* handler */
@@ -182,14 +223,28 @@ extern NXDisplayBlockHandler NXSetDisplayBlockHandler(
 );
 
 /*
+ * Called after more data is written to the display.
+ * When the NX transport is running, data may be queued
+ * until an explicit flush.
+ */
+
+extern NXDisplayWriteHandler NXSetDisplayWriteHandler(
+#if NeedFunctionPrototypes
+    NXDisplayWriteHandler /* handler */
+#endif
+);
+
+/*
+ * Called after more data is sent to the remote proxy.
+ *
  * Here the display pointer is passed as the second
  * parameter to make clear that the function does not
  * tie the callback to the display, but, similarly to
  * all the Xlib error handlers, to a global variable
  * shared by all the Xlib functions. The display
  * pointer will be passed back by nxcomp at the time
- * it will call the handler, because nxcomp doesn't
- * have access to the display structure.
+ * it will call the handler. This is because nxcomp
+ * doesn't have access to the display structure.
  */
 
 extern NXDisplayFlushHandler NXSetDisplayFlushHandler(
@@ -199,20 +254,6 @@ extern NXDisplayFlushHandler NXSetDisplayFlushHandler(
 #endif
 );
 
-extern NXDisplayCongestionHandler NXSetDisplayCongestionHandler(
-#if NeedFunctionPrototypes
-    NXDisplayCongestionHandler /* handler */,
-    Display*                   /* display */
-#endif
-);
-
-extern NXDisplaySynchronizationHandler NXSetDisplaySynchronizationHandler(
-#if NeedFunctionPrototypes
-    NXDisplaySynchronizationHandler /* handler */,
-    Display*                        /* display */
-#endif
-);
-
 /*
  * Get an arbitrary null terminated buffer to be added
  * to the NX statistics.
@@ -693,51 +734,11 @@ extern NXPackedImage *NXEncodePng(
 #endif
 );
 
-typedef struct _NXRDPGlyph {
-    Pixmap      pixmap;
-    int         x;      /* x offset */
-    int         y;      /* y baseline */
-    int         width;  /* glyph width */
-    int         height; /* glpyph height */
-} xNXRDPGlyph;
-
-typedef struct _NXRDPText {
-    unsigned int  fgColor;   /* foreground color */
-    unsigned int  bgColor;   /* background color */
-    int           fillStyle; /* fill style */
-    unsigned int  elements;  /* number of _NXRDPGlyph structs that follow this header,
-                                by the moment this information is repeated in the
-                                width field of the NXPackedImage structure. */
-} xNXRDPText;
-
-#define _NXRDPTextUnpackSize(elements) ((sz_xChangeGCReq + (4 * 3)) + \
-                                             ((sz_xChangeGCReq + (4 * 3)) + \
-                                                   (sz_xPolyFillRectangleReq + (1 * 8))) * elements)
-extern NXPackedImage *NXEncodeRDPText(
+extern NXPackedImage *NXEncodeBitmap(
 #if NeedFunctionPrototypes
-    Display*            /* display */,
-    unsigned int        /* background color */,
-    unsigned int        /* foreground color */,
-    int                 /* fill style */,
-    xNXRDPGlyph*        /* array of RDP Glyph structs */,
-    int                 /* number of elements in the RDPGlyph array */
-#endif
-);
-
-extern int NXEncodeTight(
-#if NeedFunctionPrototypes
-    Display*            /* display */,
-    Drawable            /* drawable */,
-    Visual*             /* visual */,
-    void*               /* gc */ ,
-    XImage*             /* image */,
+    XImage*             /* src_image */,
     unsigned int        /* method */,
-    int                 /* src_x */,
-    int                 /* src_y */,
-    int                 /* dst_x */,
-    int                 /* dst_y */,
-    unsigned int        /* width */,
-    unsigned int        /* height */
+    unsigned int        /* quality */
 #endif
 );
 
